@@ -26,13 +26,13 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20428 $
+ * $Revision: 21788 $
  * $Author: rjongbloed $
- * $Date: 2008-06-10 13:59:48 +0200 (mar 10 jun 2008) $
+ * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
  */
 
-#ifndef _PCHANNEL
-#define _PCHANNEL
+#ifndef PTLIB_CHANNEL_H
+#define PTLIB_CHANNEL_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
@@ -711,6 +711,8 @@ class PChannel : public PObject, public iostream {
 
 };
 
-#endif
+
+#endif // PTLIB_CHANNEL_H
+
 
 // End Of File ///////////////////////////////////////////////////////////////
