@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22601 $
- * $Author: csoutheren $
- * $Date: 2009-05-13 14:06:39 +0000 (Wed, 13 May 2009) $
+ * $Revision: 22731 $
+ * $Author: rjongbloed $
+ * $Date: 2009-05-27 01:38:51 +0000 (Wed, 27 May 2009) $
  */
 
 #include <ptlib.h>
@@ -56,12 +56,6 @@ extern "C" int vsprintf(char *, const char *, va_list);
 #define __CLASS__ GetClass()
 
 
-#ifdef __GNUC__
-
-#include <ext/pool_allocator.h>
-#include <ext/mt_allocator.h>
-
-#endif
 
 ///////////////////////////////////////////////////////////////////////////////
 //
