@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22156 $
+ * $Revision: 22614 $
  * $Author: rjongbloed $
- * $Date: 2009-03-04 06:28:29 +0000 (Wed, 04 Mar 2009) $
+ * $Date: 2009-05-14 01:58:18 +0000 (Thu, 14 May 2009) $
  */
 
 #include <ptlib.h>
@@ -416,6 +416,18 @@ PBoolean PTrace::CanTrace(unsigned level)
   return level <= PTraceInfo::Instance().thresholdLevel;
 }
 
+static PThread::TraceInfo * AllocateTraceInfo()
+{
+  PTraceInfo & info = PTraceInfo::Instance();
+
+  PThread::TraceInfo * threadInfo = info.traceStorageKey.Get();
+  if (threadInfo == NULL) {
+    threadInfo = new PThread::TraceInfo;
+    info.traceStorageKey.Set(threadInfo);
+  }
+  return threadInfo;
+}
+
 
 ostream & PTrace::Begin(unsigned level, const char * fileName, int lineNum)
 {
@@ -441,10 +453,7 @@ ostream & PTrace::Begin(unsigned level, const char * fileName, int lineNum)
 
 #if P_HAS_THREADLOCAL_STORAGE
   {
-    if (info.traceStorageKey.Get() == NULL) 
-      info.traceStorageKey.Set(new PThreadLocalStorage<PThread::TraceInfo>::value_type());
-
-    threadInfo = info.traceStorageKey.Get();
+    threadInfo = AllocateTraceInfo();
     threadInfo->traceStreams.Push(new PStringStream);
   }
 #else
@@ -535,11 +544,7 @@ ostream & PTrace::End(ostream & paramStream)
   PThread::TraceInfo * threadInfo = NULL;
 
 #if P_HAS_THREADLOCAL_STORAGE
-  {
-    if (info.traceStorageKey.Get() == NULL) 
-      info.traceStorageKey.Set(new PThreadLocalStorage<PThread::TraceInfo>::value_type());
-    threadInfo = info.traceStorageKey.Get();
-  }
+  threadInfo = AllocateTraceInfo();
 #else
   PThread * thread = PThread::Current();
   {
@@ -588,12 +593,7 @@ PTrace::Block::Block(const char * fileName, int lineNum, const char * traceName)
     PThread::TraceInfo * threadInfo = NULL;
 
 #if P_HAS_THREADLOCAL_STORAGE
-    {
-      PThreadLocalStorage<PThread::TraceInfo> & key = PTraceInfo::Instance().traceStorageKey;
-      if (key.Get() == NULL) 
-        key.Set(new PThreadLocalStorage<PThread::TraceInfo>::value_type());
-      threadInfo = key.Get();
-    }
+    threadInfo = AllocateTraceInfo();
 #else
     {
       PThread * thread = PThread::Current();
@@ -620,12 +620,7 @@ PTrace::Block::~Block()
     PThread::TraceInfo * threadInfo = NULL;
 
 #if P_HAS_THREADLOCAL_STORAGE
-    {
-      PThreadLocalStorage<PThread::TraceInfo> & key = PTraceInfo::Instance().traceStorageKey;
-      if (key.Get() == NULL) 
-        key.Set(new PThreadLocalStorage<PThread::TraceInfo>::value_type());
-      threadInfo = key.Get();
-    }
+    threadInfo = AllocateTraceInfo();
 #else
     {
       PThread * thread = PThread::Current();
@@ -913,6 +908,8 @@ PTimeInterval PTimerList::Process()
 
   PWaitAndSignal l(timerListMutex);
 
+  PTRACE(5, "PTLib\tMONITOR:timers=" << activeTimers.size());
+
   // process the requests in the timer request queue
   while (!requestQueue.empty()) {
     queueMutex.Wait();
@@ -1536,7 +1533,8 @@ static PProcessStartupList & GetPProcessStartupList()
 
 
 PProcess::PProcess(const char * manuf, const char * name,
-                           WORD major, WORD minor, CodeStatus stat, WORD build)
+                   WORD major, WORD minor, CodeStatus stat, WORD build,
+                   bool library)
   : terminationValue(0)
   , manufacturer(manuf)
   , productName(name)
@@ -1545,10 +1543,10 @@ PProcess::PProcess(const char * manuf, const char * name,
   , status(stat)
   , buildNumber(build)
   , maxHandles(INT_MAX)
-  , m_library(false)
+  , m_library(library)
 {
   activeThreads.DisallowDeleteObjects();
-  activeThreads.SetAt((PINDEX)GetCurrentThreadId(), this);
+  activeThreads.SetAt((uintptr_t)GetCurrentThreadId(), this);
 
   PProcessInstance = this;
 
@@ -1912,7 +1910,7 @@ PThread * PThread::Current()
   PProcess & process = PProcess::Current();
 
   process.activeThreadMutex.Wait();
-  PThread * thread = process.activeThreads.GetAt((unsigned)GetCurrentThreadId());
+  PThread * thread = process.activeThreads.GetAt((uintptr_t)GetCurrentThreadId());
   process.activeThreadMutex.Signal();
 
   if (thread == NULL)
@@ -2210,21 +2208,21 @@ PReadWriteMutex::~PReadWriteMutex()
 PReadWriteMutex::Nest * PReadWriteMutex::GetNest() const
 {
   PWaitAndSignal mutex(nestingMutex);
-  return nestedThreads.GetAt(POrdinalKey((PINDEX)PThread::GetCurrentThreadId()));
+  return nestedThreads.GetAt(POrdinalKey((INT)PThread::GetCurrentThreadId()));
 }
 
 
 void PReadWriteMutex::EndNest()
 {
   nestingMutex.Wait();
-  nestedThreads.RemoveAt(POrdinalKey((PINDEX)PThread::GetCurrentThreadId()));
+  nestedThreads.RemoveAt(POrdinalKey((INT)PThread::GetCurrentThreadId()));
   nestingMutex.Signal();
 }
 
 
 PReadWriteMutex::Nest & PReadWriteMutex::StartNest()
 {
-  POrdinalKey threadId = (PINDEX)PThread::GetCurrentThreadId();
+  POrdinalKey threadId = (INT)PThread::GetCurrentThreadId();
 
   nestingMutex.Wait();
 
